# **Citing QuanEstimation**

If you use QuanEstimation in your research, please cite the following paper:

[1] M. Zhang, H.-M. Yu, H. Yuan, X. Wang, R. Demkowicz-Dobrzański, and J. Liu, 
QuanEstimation: an open-source toolkit for quantum parameter estimation, 
[arXiv:2205.15588](https://doi.org/10.48550/arXiv.2205.15588).

